# WiFi-DMD flow of MLD configuration

## Set MLD Unit of SSID

#### if (MLDUnit != -1):
 - If MLDUnit value is 0, return Error.
 - If the corresponding SSID whose MLDUnit is updated, not associated with an AP then return Error.
 - Validate the mlo capability of the radio assigned to the SSID
    - False:
        - If LowerLayer(radio device) of the SSID is not configured, return Error
        - If the mlo capability of the radio is not true, return Error
    - True:
        - Check if the **wifi-mld** section for configured MLDUnit is already exist in **wireless** UCI
            - False:
                - Create a new **wifi-mld** section in **wireless**.
                - Set options *ssid*, *ifname*, *key*, *sae-pwe* of the new *wifi-mld* section.
                - *ssid*, *key* and *sae-pwe* is copied from the *wifi-iface* section of the corresponding SSID/AP.
                - *ifname* is populated as *wlan(mld_id-1)* i.e if mld_id is 2 then *ifname* is wlan1
                - If **mapcontroller** UCI file exists
                    - True:
                        - Create a new **mld** section in **mapcontroller** UCI
                        - Set options *id*, *ssid*, *key*, *type* of the new *mld* section.
                        - *ssid*, *key* copied from the **wifi-iface** section of the SSID/AP, *id* is set to the MLDUnit and *type* set to fronthaul.
                    - False:
                        - Do nothing.
            - True:
                - Do nothing
        - Update AP section in **mapcontroller** UCI only if the file exists
            - If *ap* section of the corresponding wireless *wifi-iface* section not exist
                - Create new **ap** section in mapcontroller and set *band*, *ssid*, *encryption*, *key*, *type* and *mld_id*.
                - *type* is set to fronthaul, *mld_id* is set with MLDUnit value and other options are copied from corresponding *wifi-iface* and *wifi-device* sections in **wireless** UCI.
            - Else
                - Only update the *mld_id* of the corresponding **ap** section with configured MLDUnit
        - Update *mld* option of the corresponding **wifi-iface** (SSID/AP) section in the **wireless** UCI.
#### else:
 - Delete *mld* option from the corresponding **wifi-iface** (SSID/AP) section in the **wireless** UCI.
 - Update AP section in **mapcontroller** UCI only if the file exists
    - If *ap* section is not exist for the corresponding *wifi-iface* section of **wireless** UCI
        - Do nothing
    - Else
        - Delete *mld* option from the **ap** section

## Changing of SSID
 - Update the `ssid` option in the corresponding **wifi-iface** section in **wireless** UCI
 - Validate the **mlo** capability
    - True:
        - If *mld* of the corresponding **wifi-iface** section is valid i.e other than -1
            - Update the *ssid* with new value in the **wifi-mld** section that refers to this *mld* unit
            - If **mapcontroller** UCI file exists
                - update the *ssid* in the corresponding **mld** section
                - update the *ssid* in the corresponding **ap** section
    - False:
        - Do nothing

## Changing of key
 - Update the `key` option in the corresponding **wifi-iface** section in **wireless** UCI
 - Validate the **mlo** capability
    - True:
        - If *mld* of the corresponding **wifi-iface** section is valid i.e other than -1
            - Update the *key* with new value in the **wifi-mld** section that refers to this *mld* unit
            - If **mapcontroller** UCI file exists
                - update the *key* in the corresponding **mld** section
                - update the *key* in the corresponding **ap** section
    - False:
        - Do nothing


## Restrictions in MLD configuration
 - MLD Unit configuration is only allowed if the Radio of the corresponding SSID has mlo capability enabled i.e **mlo_capable** param under **wifi-device** section.
 - MLD Unit value 0 is restricted as this unit id is used to assume the ifname in the **wifi-mld** section.
 - No pre-validation is performed before setting the MLD unit that if the configured MLD unit does belong to Backhaul or Fronthaul.
 - Key for MLD section is only considered to SAEPassphrase.


## Open Queries
 - Do we need to copy more option or remove any option in **wifi-mld** section from **wifi-iface** while creating new MLD?
 - Do we need to create a new **ap** section in mapcontroller while creating a new Access Point in **wireless**? If yes, then which are the options we need to set under **ap** section?
 - While updating MLDUnit of any SSID do we need to validate if that mld belongs to fronthaul before updating?
 - How to configure encryption in MLD sections (In wireless as well as mapcontroller UCI) and what are the supported modes?

